import React from 'react'
import { translate } from 'cozy-ui/react/I18n'

import IFluidConfig from 'services/IFluidConfig'

import iconGRDFLogo from 'assets/icons/visu/grdf-logo.svg'
import iconEGLLogo from 'assets/icons/visu/egl-logo.svg'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import StyledButton from 'components/CommonKit/Button/StyledButton'
import StyledNoOauthButton from 'components/CommonKit/Button/StyledOauthButton'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import TrailingIcon from 'assets/icons/ico/trailing-icon.svg'

interface KonnectorFormProps {
  fluidConfig: IFluidConfig
  login: string
  setLogin: Function
  password: string
  setPassword: Function
  loading: boolean
  error: string
  handleSubmit: Function
  t: Function
}

const KonnectorForm: React.FC<KonnectorFormProps> = ({
  fluidConfig,
  login,
  setLogin,
  password,
  setPassword,
  loading,
  error,
  handleSubmit,
  t,
}: KonnectorFormProps) => {
  const konnectorName: string = fluidConfig.konnectorConfig.name
  const konnectorType: string = fluidConfig.konnectorConfig.type
  const siteLink: string = fluidConfig.siteLink

  function revealPassword(idInput: string) {
    const input = document.getElementById(idInput)
    if (input) {
      if (input.getAttribute('type') === 'password') {
        input.setAttribute('type', 'text')
      } else {
        input.setAttribute('type', 'password')
      }
    }
  }

  const getIcon = (fluidName: string) => {
    switch (fluidName) {
      case 'grdf':
        return iconGRDFLogo
      case 'egl':
        return iconEGLLogo
      default:
        return null
    }
  }

  const icon = getIcon(fluidConfig.name)

  return (
    <form
      className="form"
      onSubmit={(e: React.FormEvent<HTMLFormElement>) => handleSubmit(e)}
    >
      <div className="text-16-normal">
        {t('KONNECTORCONFIG.LABEL_FILLIN')} {konnectorName}
      </div>

      <div className="form-group">
        <div className="form-message">{error}</div>
        <input
          id={'idFieldLogin' + konnectorType}
          type="text"
          className="form-control form-input"
          aria-describedby="emailHelp"
          placeholder="Adresse e-mail"
          name="login"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setLogin(e.target.value)
          }
          value={login}
        ></input>
      </div>

      <div className="form-group">
        <div className="form-message">{error}</div>
        <input
          id={'idFieldPassword' + konnectorType}
          type="password"
          className="form-control form-input"
          aria-describedby="PasswordHelp"
          placeholder="Mot de passe"
          name="password"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setPassword(e.target.value)
          }
          value={password}
        />
        <span>
          <StyledIconButton
            icon={TrailingIcon}
            className="form-trailing-icon"
            size={22}
            onClick={() => revealPassword('idFieldPassword' + konnectorType)}
          />
        </span>
      </div>

      <div className="koauthform-button">
        <StyledNoOauthButton type="submit" color="primary">
          <div className="oauthform-button-content">
            <div className="oauthform-button-content-icon">
              {icon && <StyledIcon icon={icon} size={48} />}
            </div>
            <div className="oauthform-button-text text-18-bold">
              <div>
                {t('nooauth.connection.text')}{' '}
                {t('nooauth.' + fluidConfig.name + '.text')}
              </div>
            </div>
          </div>
        </StyledNoOauthButton>
      </div>
      <br />
      <div className="koauthform-text text-16-bold">
        <div className="text-16-bold">
          {t('nooauth.creation.no_account')}{' '}
          {t('nooauth.' + fluidConfig.name + '.text')} ?
        </div>
        <div className="text-16-normal">
          {t('nooauth.creation.text')}{' '}
          {t('nooauth.' + fluidConfig.name + '.facture')}
        </div>
      </div>

      <StyledButton
        type="button"
        color="secondary"
        disabled={loading}
        onClick={() => window.open(siteLink, '_blank')}
      >
        {t('nooauth.creation.button_text')}{' '}
        {t('nooauth.' + fluidConfig.name + '.short_text')}
      </StyledButton>
    </form>
  )
}

export default translate()(KonnectorForm)
