import React, { useState, useEffect } from 'react'
import { withClient, Client } from 'cozy-client'

import { Konnector } from 'doctypes'
import KonnectorService from 'services/konnectorService'
import KonnectorStatusService from 'services/konnectorStatusService'

import KonnectorViewerCard from 'components/ContentComponents/KonnectorViewer/KonnectorViewerCard'
import IFluidConfig from 'services/IFluidConfig'

export interface KonnectorViewerProps {
  fluidConfig: IFluidConfig
  client: Client
  isParam: boolean
}

const KonnectorViewer: React.FC<KonnectorViewerProps> = ({
  fluidConfig,
  client,
  isParam = false,
}: KonnectorViewerProps) => {
  const [konnector, setKonnector] = useState<Konnector | null>(null)
  const [lastTrigger, setLastTrigger] = useState<any>(null)

  useEffect(() => {
    let subscribed = true
    const konnectorService = new KonnectorService(
      client,
      fluidConfig.konnectorConfig.slug
    )
    const kss = new KonnectorStatusService(client)

    async function getData() {
      const _konnector: Konnector = await konnectorService.fetchKonnector()
      if (!_konnector || !_konnector.slug) {
        throw new Error(
          `Could not find konnector for ${fluidConfig.konnectorConfig.slug}`
        )
      }
      if (subscribed && _konnector) {
        setKonnector(_konnector)
      }

      const allTriggers = await kss.getAllTriggers()
      if (allTriggers) {
        const lastTrigger = allTriggers
          .filter(
            trigger =>
              trigger.worker === 'konnector' &&
              trigger.message.konnector === fluidConfig.konnectorConfig.slug
          )
          .sort((a, b) => (new Date(a) > new Date(b) ? 1 : -1))
          .shift()
        if (subscribed && lastTrigger) {
          setLastTrigger(lastTrigger)
        }
      }
    }

    getData()
    return () => {
      subscribed = false
    }
  }, [])

  return (
    <>
      {!konnector ? null : (
        <KonnectorViewerCard
          fluidConfig={fluidConfig}
          konnector={konnector}
          trigger={lastTrigger}
          isParam={isParam}
        />
      )}
    </>
  )
}

export default withClient(KonnectorViewer)
